@@ -1176,7 +1176,9 @@ extOutputTrans(def, transList, outFile)
 	/* Set all terminals to NULL to guard against	*/
 	/* asymmetric devices missing a terminal.	*/
 	nsd = ExtCurStyle->exts_transSDCount[t];
-	for (i = 0; i < nsd; i++) extTransRec.tr_termnode[i] = NULL;
+	/* NOTE:  This was nsd, but leaves non-NULL terminals	*/
+	/* when minterms < maxterms. . .			*/
+	for (i = 0; i < MAXSD; i++) extTransRec.tr_termnode[i] = NULL;
 
 	/* Mark with reg and process each perimeter segment */
 	arg.fra_uninit = (ClientData) extTransRec.tr_gatenode;
@@ -1319,7 +1321,8 @@ extOutputTrans(def, transList, outFile)
 
 		if (n == 0)
 		{
-		    if (ExtDoWarn)
+		    /* Don't issue warning on devices with no declared terminals */
+		    if (ExtDoWarn && (ExtCurStyle->exts_transSDCount[t] > 0))
 			extTransBad(def, reg->treg_tile,
 				"Could not determine device boundary");
 		    length = width = 0;
@@ -1425,18 +1428,14 @@ extOutputTrans(def, transList, outFile)
 		/* Boundary perimeter scan for resistors with more than */
 		/* one tile.						*/
 
-		if (ntiles > 1)
-		{
-		    LinkedBoundary *lb;
-
-		    for (n = 0; n < extTransRec.tr_nterm &&
+		for (n = 0; n < extTransRec.tr_nterm &&
 				extTransRec.tr_termnode[n] != NULL; n++);
 
-		    if (n == 0)
-		    {
-			width = 0;
-			goto outputrsub;
-		    }
+		if (n == 0)
+		    width = length = 0;
+		else if (ntiles > 1)
+		{
+		    LinkedBoundary *lb;
 
 		    extSpecialBounds = (LinkedBoundary **)mallocMagic(n *
 				sizeof(LinkedBoundary *));
@@ -1493,7 +1492,6 @@ extOutputTrans(def, transList, outFile)
 		    width >>= 1;
 		    length >>= 1;
 		}
-outputrsub:
 		if (width)
 		{
 		    dres = ExtCurStyle->exts_sheetResist[t] * (double)length /
@@ -1780,7 +1778,6 @@ extTransTileFunc(tile, pNum)
     if (IsSplit(tile))
     {
         loctype = (SplitSide(tile)) ? SplitRightType(tile): SplitLeftType(tile);
-	return (0); 	/* Hack alert!  We must properly handle diagonals! */
     }
     else
 #endif
@@ -1859,9 +1856,7 @@ extTransPerimFunc(bp)
 		}
 	    }
 	    else
-	    {
 		TxError("Error:  Asymmetric device with multiple terminals!\n");
-	    }
 
 	    /* Add the length to this terminal's perimeter */
 	    extTransRec.tr_termlen[thisterm] += len;
@@ -2345,6 +2340,51 @@ extLabType(text, typeMask)
 }
 
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * extNodeToTile --
+ *
+ *	Sets tp to be the tile containing the lower-leftmost point of the
+ *	NodeRegion *np, but in the tile planes of the ExtTree *et instead
+ *	of the tile places originally containing *np.  This routine used
+ *	to be defined as the macro NODETOTILE().
+ *
+ * Results:
+ *	Returns a pointer to the tile
+ *
+ * Side effects:
+ *	None. 
+ * ----------------------------------------------------------------------------
+ */
+
+Tile *extNodeToTile(np, et)
+    NodeRegion *np;
+    ExtTree *et;
+{
+    Tile *tp;
+    Plane *myplane;
+
+    myplane = et->et_use->cu_def->cd_planes[np->nreg_pnum];
+
+    tp = myplane->pl_hint;
+    GOTOPOINT(tp, &np->nreg_ll);
+    myplane->pl_hint = tp;
+
+#ifdef NONMANHATTAN
+    if (IsSplit(tp))
+    {
+	TileType tpt = TiGetTypeExact(tp);
+	if ((tpt & TT_LEFTMASK) == (np->nreg_type & TT_LEFTMASK))
+	    TiSetBody(tp, tpt & ~TT_SIDE);
+	else
+	    TiSetBody(tp, tpt | TT_SIDE);
+    }
+#endif
+
+    return tp;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2375,12 +2415,23 @@ extSetNodeNum(reg, plane, tile)
     TileType type;
 
 #ifdef NONMANHATTAN
-    type = SplitSide(tile) ? SplitRightType(tile) : SplitLeftType(tile);
-#else
-    type = TiGetType(tile);
-#endif
+    if (IsSplit(tile))
+    {
+	/* Only consider split tiles if the lower-left-hand corner	*/
+	/* is only the type under consideration.			*/
 
-    if (plane < reg->lreg_pnum)
+	if (!SplitSide(tile) && SplitDirection(tile))
+	    type = SplitSide(tile) ? SplitRightType(tile) : SplitLeftType(tile);
+	else if (reg->lreg_pnum == DBNumPlanes)
+	    type = TiGetTypeExact(tile);
+	else
+	    return;
+    }
+    else
+#endif
+	type = TiGetType(tile);
+
+    if ((plane < reg->lreg_pnum) || (reg->lreg_type & TT_DIAGONAL))
     {
 	reg->lreg_type = type;
 	reg->lreg_pnum = plane;
@@ -2658,6 +2709,28 @@ extNodeAreaFunc(tile, arg)
 	    extResistArea[resistClass] += area;
 	reg->nreg_cap += area * ExtCurStyle->exts_areaCap[residue];
 
+#ifdef NONMANHATTAN
+	if (IsSplit(tile))
+	{
+	    len = ((RIGHT(tile) - LEFT(tile)) * (RIGHT(tile) - LEFT(tile))) +
+			((TOP(tile) - BOTTOM(tile)) * (TOP(tile) - BOTTOM(tile)));
+	    len = (int)sqrt((double)len);
+
+	    if (extNodeClipArea)
+	    {
+		/* To-do:  Find perimeter length of clipped edge */
+	    }	
+
+	    /* Find the type on the other side of the tile */
+	    t = (SplitSide(tile)) ? SplitLeftType(tile): SplitRightType(tile);
+	    tres = (DBIsContact(t)) ? DBPlaneToResidue(t, tilePlaneNum) : t;
+	    if ((capval = ExtCurStyle->exts_perimCap[residue][tres]) != (CapValue) 0)
+		reg->nreg_cap += capval * len;
+	    if (TTMaskHasType(resMask, tres) && resistClass != -1)
+		extResistPerim[resistClass] += len;
+	}
+#endif
+
 	/*
 	 * Walk along all four sides of tile.
 	 * Sum perimeter capacitance as we go.
